% MalariaSim
% Advanced model to simulate dynamics in malaria epidemy
% ---------------------------------------
% ----- Unknowns
% S_h(t)  Number of susceptible humans at time t.
% Eh(t)   Number of humans exposed to malaria infection at time t.
% Ih(t)   Number of infected humans at time t.
% Rh (t)  Number of recovered humans at time t.
% Sm (t)  Number of susceptible mosquitoes at time t.
% Em (t)  Number of exposed mosquitoes at time t.
% Im (t)  Number of infectious mosquitoes at time t.
% ----- parameters 
% Lambda_h  Birth number of humans.
% Lambda_m  Birth number of mosquitoes.
% b         Biting rate of the mosquito.
% beta_h    Probability that a bite by an infectious mosquito results 
%           in transmission of disease to human.
% beta_m    Probability that a bite results in transmission of parasite 
%           to a susceptible mosquito.
% mu_h      Per capita rate of human mortality.
% mu_m      Per capita rate of mosquito mortality.
% delta_h   Disease induced death rate of human.
% delta_m   Disease induced death rate of mosquito.
% alfa_h    Per capital rate of progression of humans from the exposed
%           state to the infectious state.
% alfa_m    Per capital rate of progression of mosquitoes from the exposed
%           state to the infectious state.
% r         Recovery rate of humans.
% omega     Per capital rate of loss of immunity in humans.
% nu_h      Proportion of an antibody produced by human in response 
%           to the incidence of infection caused by mosquito.
% nu_m      Proportion of an antibody produced by mosquito in response 
%           to the incidence of infection caused by human.

% Set start- and end-time of the simulation
starttid = 0;
sluttid = 120;
tidsintervall = [starttid sluttid];

% set parameters parametrarna

Lambda_h = 20;
Lambda_m = 40;
b        = 0.075; 
beta_h   = 0.3;    
beta_m   = 0.5;       
mu_h     = 0.015;
mu_m     = 0.02;
delta_h  = 0.05;
delta_m  = 0.15;
alfa_h   = 0.6;      
alfa_m   = 0.6;
r        = 0.05;
omega    = 0.02;
nu_h     = 0.5;        
nu_m     = 0.5;

% ----- Initial values of the variables at time 0
S_h0 = 900;
S_m0 = 900;
E_h0 = 30;
E_m0 = 330;
I_h0 = 50;
I_m0 = 270;
R_h0 = 20;

y0 = [...]; % initial vector
param = [...]; % vector with parameters

% ----- Set the parameters for the Matlab solver
%val = odeset('OutputFcn','odeplot','RelTol', 1e-1);
val = odeset;

% Choose an ODE solver
[t_RK4, y_RK4] = ode45(@(t,y) myMalariaODE(t,y,param), tidsintervall, y0, val);
h=...
[t, y] = Ralston...

%----- plot the solution 

figure(1),clf,hold
plot(t,y(:,1),'b--')
plot(t,y(:,2),'b.')
plot(t,y(:,3),'m--')
plot(t,y(:,4),'m.')
plot(t,y(:,5),'r--')
plot(t,y(:,6),'r.')
plot(t,y(:,7),'g--')

 xlabel('tid')
 title('Simulation of malaria epidemy');
 legend('susseptible (h)','susseptible (m)','exposed (h)','exposed (m)','infected (h)','infectios (m)','recovered (h)');

% possibly compare with the solution from ode45
 %figure(2),clf
 %plot(t,y(:,1),'b*'),hold
 %plot(t_RK4,y_RK4(:,1),'mo')
