function w = Malaria_prop(y, param)
%
% Propensities, w, for the Malaria model model.
% 
% Input: y - the current state vector y(1:7) 
%        p - list of parameters)
%
% Order of the unknowns: [S_h; S_m; E_h; E_m; I_h; I_m; R_h]
%                        [y(1),y(2),y(3),y(4),y(5),y(6),y(7)]
%
Lambda_h = param(1,1) ;
Lambda_m = param(2,1) ;
b        = param(3,1) ;
beta_h   = param(4,1) ;
beta_m   = param(5,1) ;
mu_h	 = param(6,1) ;
mu_m	 = param(7,1) ;
delta_h  = param(8,1) ;
delta_m  = param(9,1) ;
alfa_h   = param(10,1);
alfa_m   = param(11,1);
r        = param(12,1);
omega	 = param(13,1);
nu_h	 = param(14,1);
nu_m	 = param(15,1);


w = [ Lambda_h;                             % 1 0 -> y(1) as Lambda_h
      mu_h*y(1);                            % 1 y(1) -> 0 as mu_h*y(1)
      (b*beta_h*y(1)*y(6))/(1+nu_h*y(6));   % 1 y(1) -> y(3) as ...
      Lambda_m;                             % 2 0 -> y(2) as Lambda_m
      mu_m*y(2);                            % 2 y(2) -> 0 as mu_m*y(2)
      (b*beta_m*y(2)*y(5))/(1+nu_m*y(5));   % 2 y(2) -> y(4) as ...     
      mu_h*y(3);                            % 3 y(3) -> 0 as mu_h*y(3)
      alfa_h*y(3);                          % 3 y(3) -> y(5) as alfa_h*y(3)
      mu_m*y(4);                            % 4 y(4) -> 0  as mu_m*y(4)
      alfa_m*y(4);                          % 4 y(4) -> y(6) as alfa_m*y(4)
      (mu_h+delta_h)*y(5);                  % 5 y(5) -> 0 as (mu_h+delta_h)*y(5)
      r*y(5);                               % 5 y(5) -> y(7) as r*y(5)
      (mu_m+delta_m)*y(6);                  % 6 y(6) -> 0 as (mu_m+delta_m)*y(6)
      omega*y(7);                           % 7 y(7) -> y(1) as omega*y(7)!
      mu_h*y(7)];                           % 7 y(7) -> 0 as mu_h*y(7)
 
end
